#!/usr/bin/env node
const path = require('path')
const chalk = require('chalk')
/** 
 * merge 直接放行，不再验证
 * 第一种：非代码冲突，自动commit成功，会走该验证函数，放行！！！(下述判断主要判断此种类型)
 * 第二种：代码冲突，通过执行 npm run commit/ yarn commit, 先执行 is-merge-commit.js 其中脚本 commit，然后跳过 git cz。
*/
const findMergeMessage = require('../utils/find-merge-message.js')
const mergeMessage = findMergeMessage(process.env.PWD || process.env.INIT_CWD)
if (!!mergeMessage) {
  process.exit(0)
}

// 常规提交
const msgPath = process.env.GIT_PARAMS
const msg = require('fs').readFileSync(msgPath, 'utf-8').trim()

const commitRE = /^(revert: )?(feat|fix|improvement|polish|docs|style|refactor|perf|test|workflow|ci|chore|types|build|merge)(\(.+\))?: .{1,50}/

if (!commitRE.test(msg)) {
  console.error(
    `  ${chalk.bgRed.white(' ERROR ')} ${chalk.red(`invalid commit message format.`)}\n\n` +
    chalk.red(`  Proper commit message format is required for automated changelog generation. Examples:\n\n`) +
    `    ${chalk.green(`feat(compiler): add 'comments' option`)}\n` +
    `    ${chalk.green(`fix(v-model): handle events on blur (close #28)`)}\n\n` +
    chalk.red(`  You can also use ${chalk.cyan(`npm run commit`)} to interactively generate a commit message.\n`)
  )
  process.exit(1)
}
